package com.ruoyi.ems.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ems.mapper.AdmEmsElecProdForecastMapper;
import com.ruoyi.ems.domain.AdmEmsElecProdForecast;
import com.ruoyi.ems.service.IAdmEmsElecProdForecastService;

/**
 * 电力产能预测Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-08-12
 */
@Service
public class AdmEmsElecProdForecastServiceImpl implements IAdmEmsElecProdForecastService 
{
    @Autowired
    private AdmEmsElecProdForecastMapper admEmsElecProdForecastMapper;

    /**
     * 查询电力产能预测
     * 
     * @param id 电力产能预测主键
     * @return 电力产能预测
     */
    @Override
    public AdmEmsElecProdForecast selectAdmEmsElecProdForecastById(Long id)
    {
        return admEmsElecProdForecastMapper.selectAdmEmsElecProdForecastById(id);
    }

    /**
     * 查询电力产能预测列表
     * 
     * @param admEmsElecProdForecast 电力产能预测
     * @return 电力产能预测
     */
    @Override
    public List<AdmEmsElecProdForecast> selectAdmEmsElecProdForecastList(AdmEmsElecProdForecast admEmsElecProdForecast)
    {
        return admEmsElecProdForecastMapper.selectAdmEmsElecProdForecastList(admEmsElecProdForecast);
    }

    /**
     * 新增电力产能预测
     * 
     * @param admEmsElecProdForecast 电力产能预测
     * @return 结果
     */
    @Override
    public int insertAdmEmsElecProdForecast(AdmEmsElecProdForecast admEmsElecProdForecast)
    {
        return admEmsElecProdForecastMapper.insertAdmEmsElecProdForecast(admEmsElecProdForecast);
    }

    /**
     * 修改电力产能预测
     * 
     * @param admEmsElecProdForecast 电力产能预测
     * @return 结果
     */
    @Override
    public int updateAdmEmsElecProdForecast(AdmEmsElecProdForecast admEmsElecProdForecast)
    {
        return admEmsElecProdForecastMapper.updateAdmEmsElecProdForecast(admEmsElecProdForecast);
    }

    /**
     * 批量删除电力产能预测
     * 
     * @param ids 需要删除的电力产能预测主键
     * @return 结果
     */
    @Override
    public int deleteAdmEmsElecProdForecastByIds(Long[] ids)
    {
        return admEmsElecProdForecastMapper.deleteAdmEmsElecProdForecastByIds(ids);
    }

    /**
     * 删除电力产能预测信息
     * 
     * @param id 电力产能预测主键
     * @return 结果
     */
    @Override
    public int deleteAdmEmsElecProdForecastById(Long id)
    {
        return admEmsElecProdForecastMapper.deleteAdmEmsElecProdForecastById(id);
    }
}
