package com.ruoyi.ems.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.AdmEmsElecProdForecast;
import com.ruoyi.ems.service.IAdmEmsElecProdForecastService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 电力产能预测Controller
 *
 * @author ruoyi
 * @date 2024-08-12
 */
@RestController
@RequestMapping("/predictionProd")
public class AdmEmsElecProdForecastController extends BaseController
{
    @Autowired
    private IAdmEmsElecProdForecastService admEmsElecProdForecastService;

    /**
     * 查询电力产能预测列表
     */
    @RequiresPermissions("prediction:prod:list")
    @GetMapping("/list")
    public TableDataInfo list(AdmEmsElecProdForecast admEmsElecProdForecast)
    {
        startPage();
        List<AdmEmsElecProdForecast> list = admEmsElecProdForecastService.selectAdmEmsElecProdForecastList(admEmsElecProdForecast);
        return getDataTable(list);
    }

    /**
     * 导出电力产能预测列表
     */
    @RequiresPermissions("prediction:prod:export")
    @Log(title = "电力产能预测", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AdmEmsElecProdForecast admEmsElecProdForecast)
    {
        List<AdmEmsElecProdForecast> list = admEmsElecProdForecastService.selectAdmEmsElecProdForecastList(admEmsElecProdForecast);
        ExcelUtil<AdmEmsElecProdForecast> util = new ExcelUtil<AdmEmsElecProdForecast>(AdmEmsElecProdForecast.class);
        util.exportExcel(response, list, "电力产能预测数据");
    }

    /**
     * 获取电力产能预测详细信息
     */
    @RequiresPermissions("prediction:prod:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(admEmsElecProdForecastService.selectAdmEmsElecProdForecastById(id));
    }

    /**
     * 新增电力产能预测
     */
    @RequiresPermissions("prediction:prod:add")
    @Log(title = "电力产能预测", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AdmEmsElecProdForecast admEmsElecProdForecast)
    {
        return toAjax(admEmsElecProdForecastService.insertAdmEmsElecProdForecast(admEmsElecProdForecast));
    }

    /**
     * 修改电力产能预测
     */
    @RequiresPermissions("prediction:prod:edit")
    @Log(title = "电力产能预测", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AdmEmsElecProdForecast admEmsElecProdForecast)
    {
        return toAjax(admEmsElecProdForecastService.updateAdmEmsElecProdForecast(admEmsElecProdForecast));
    }

    /**
     * 删除电力产能预测
     */
    @RequiresPermissions("prediction:prod:remove")
    @Log(title = "电力产能预测", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(admEmsElecProdForecastService.deleteAdmEmsElecProdForecastByIds(ids));
    }
}
